function fs = fourier_compute_coefficients(vs, nf)
    % fs takes form  [b_m, ..., b_1, a_0, a_1, ..., a_m]  for n=2m+1
    % or  [b_m, ..., b_1, a_0, a_1, ..., a_m, a_m+1]  when n = 2m+2
    % representing  q(x) = a_0 + sum a_i cos(...) + sum b_i sin(...)
    nv = numel(vs);
    if nargin < 2
        nf = nv;
    end
    mv = floor((nv-1)/2);
    lv = nv-mv-1;
    mf = floor((nf-1)/2);
    m = min(mv, mf);
    l = min(lv, nf-mf-1);

    vs = fft(vs);
    vs(1) = vs(1) / 2;
    if lv ~= mv
        vs(lv+1) = vs(lv+1) / 2;
    end

    fs = zeros(1, nf);
    fs(mf-m+1:mf) = 2*imag(vs(nv-m+1:nv)) / nv;
    fs(mf+1:mf+l+1) = 2*real(vs(1:l+1)) / nv;
end