function [mbp, hmax] = generate_test_parametrisation(name)
    if nargin < 1
        name = 'trefoil';
    end
    switch name
        case 'rhopalocera'
            rx = 0.6;
            ry = 0.4;
            a = -1;
            b = -1/6;
            c = 5/6;
            mbp = generate_lepidoptera_parametrisation(rx, ry, a, b, c);
            w = 6;
            a = 0.05;
            p = 0.3;
            r = @(s) 0.1 + a * cos(w*pi*(s-p));
            dr = @(s) -a*w*pi * sin(w*pi*(s-p));
            d2r = @(s) -a*w^2*pi^2 * cos(w*pi*(s-p));
            no = -1;
            xc = [-0.43; 0.18];
            mbp = add_star_shaped_parametrisation(mbp, xc, no, r, dr, d2r);
            a = -a;
            r = @(s) 0.1 + a * cos(w*pi*(s+p));
            dr = @(s) -a*w*pi * sin(w*pi*(s+p));
            d2r = @(s) -a*w^2*pi^2 * cos(w*pi*(s+p));
            xc = [0.43; 0.18];
            mbp = add_star_shaped_parametrisation(mbp, xc, no, r, dr, d2r);
            a = 0.045;
            p = -0.3;
            r = @(s) 0.1 + a * cos(w*pi*(s-p));
            dr = @(s) -a*w*pi * sin(w*pi*(s-p));
            d2r = @(s) -a*w^2*pi^2 * cos(w*pi*(s-p));
            no = -1;
            xc = [-0.4; -0.2];
            mbp = add_star_shaped_parametrisation(mbp, xc, no, r, dr, d2r);
            a = -a;
            r = @(s) 0.1 + a * cos(w*pi*(s+p));
            dr = @(s) -a*w*pi * sin(w*pi*(s+p));
            d2r = @(s) -a*w^2*pi^2 * cos(w*pi*(s+p));
            xc = [0.4; -0.2];
            mbp = add_star_shaped_parametrisation(mbp, xc, no, r, dr, d2r);
            hmax = 0.02;

        case 'genus5'
            mbp = struct([]);
            r = @(s) 0.5*ones(size(s));
            dr = @(s) zeros(size(s));
            d2r = @(s) zeros(size(s));
            no = 1;
            xc = [0; 0];
            mbp = add_star_shaped_parametrisation(mbp, xc, no, r, dr, d2r);
            r = @(s) 0.1*ones(size(s));
            dr = @(s) zeros(size(s));
            d2r = @(s) zeros(size(s));
            no = -1;
            n = 5;
            for ii=0:n-1
                xc = 0.25 * [cos(ii/n*2*pi); sin(ii/n*2*pi)];
                mbp = add_star_shaped_parametrisation(mbp, xc, no, r, dr, d2r);
            end
            hmax = 0.04;

        case 'genus3'
            mbp = struct([]);
            r = @(s) 0.5*ones(size(s));
            dr = @(s) zeros(size(s));
            d2r = @(s) zeros(size(s));
            no = 1;
            xc = [0; 0];
            mbp = add_star_shaped_parametrisation(mbp, xc, no, r, dr, d2r);
            r = @(s) 0.15*ones(size(s));
            dr = @(s) zeros(size(s));
            d2r = @(s) zeros(size(s));
            no = -1;
            n = 3;
            for ii=0:n-1
                xc = 0.25 * [cos(ii/n*2*pi); sin(ii/n*2*pi)];
                mbp = add_star_shaped_parametrisation(mbp, xc, no, r, dr, d2r);
            end
            hmax = 0.06;
            
        case 'ring'
            mbp = struct([]);
            r = @(s) 0.75*ones(size(s));
            dr = @(s) zeros(size(s));
            d2r = @(s) zeros(size(s));
            no = 1;
            xc = [0; 0];
            mbp = add_star_shaped_parametrisation(mbp, xc, no, r, dr, d2r);
            r = @(s) 0.3*ones(size(s));
            dr = @(s) zeros(size(s));
            d2r = @(s) zeros(size(s));
            no = -1;
            xc = [0; 0];
            mbp = add_star_shaped_parametrisation(mbp, xc, no, r, dr, d2r);
            hmax = 0.1875;

        case 'circle'
            mbp = struct([]);
            r = @(s) 0.8*ones(size(s));
            dr = @(s) zeros(size(s));
            d2r = @(s) zeros(size(s));
            no = 1;
            xc = [0; 0];
            mbp = add_star_shaped_parametrisation(mbp, xc, no, r, dr, d2r);
            hmax = 0.48;

        otherwise %trefoil
            mbp = struct([]);
            w = 6;
            a = 0.3;
            r = @(s) 0.5 + a * cos(w*pi*s);
            dr = @(s) -a*w*pi * sin(w*pi*s);
            d2r = @(s) -a*w^2*pi^2 * cos(w*pi*s);
            no = 1;
            xc = [0; 0];
            mbp = add_star_shaped_parametrisation(mbp, xc, no, r, dr, d2r);
            hmax = 0.18;
    end
end