function dcd = interpolate_cauchy_data(mbp, ns, u, dnu)
    r = numel(mbp);

    % pre-allocate dcd fields
    dcd(r).n = 0;
    dcd(r).ts = [];
    dcd(r).ws = [];
    dcd(r).wls = [];

    dcd(r).gammas = [];
    dcd(r).normdgammas = [];
    dcd(r).d2gammas = [];
    dcd(r).ngammas = [];

    dcd(r).rhoDs = [];
    dcd(r).rhoNs = [];

    % compute dcd fields
    for ll=1:r
        n = ns(ll);
        llts = circular_quadrature_nodes(n);
        dcd(ll).n = n;
        dcd(ll).ts = llts;
        dcd(ll).ws = circular_quadrature_weights(n);
        dcd(ll).wls = circular_quadrature_weights_log(n);

        dcd(ll).gammas = mbp(ll).gamma(llts);
        dcd(ll).normdgammas = vecnorm(mbp(ll).dgamma(llts));
        dcd(ll).d2gammas = mbp(ll).d2gamma(llts);
        dcd(ll).ngammas = mbp(ll).ngamma(llts);

        dcd(ll).rhoDs = u(dcd(ll).gammas);
        dcd(ll).rhoNs = dnu(dcd(ll).gammas, dcd(ll).ngammas);
    end
end